# MILI <small>0.9.6</small>

Minimal immediate-mode python user interface library.

You can find MILI at its latest version on [**PyPI**](https://pypi.org/project/mili-ui/) and install it and import it using the following command and code:

```sh
pip install mili-ui
```

```py
import mili
```

# [<small>MILI Guide</small>](https://github.com/damusss/mili/blob/main/guide/guide.md)

After installing MILI you may also open the guide using the following command:

```sh
py -m mili guide
```
